@@ -8,55 +8,11 @@
 
 #include <alpm.h>
 
-/* These are missing in alpm.h */
-
-/* from deps.h */
-struct __pmdepend_t {
-	pmdepmod_t mod;
-	char *name;
-	char *version;
-};
-
-struct __pmdepmissing_t {
-	char *target;
-	pmdepend_t *depend;
-	char *causingpkg; /* this is used in case of remove dependency error only */
-};
-
-/* from group.h */
-struct __pmgrp_t {
-	/*group name*/
-	char *name;
-	/*list of pmpkg_t packages*/
-	alpm_list_t *packages;
-};
-
-/* from sync.h */
-struct __pmsyncpkg_t {
-	pmpkgreason_t newreason;
-	pmpkg_t *pkg;
-	alpm_list_t *removes;
-};
-
-/* from conflicts.h */
-
-struct __pmconflict_t {
-    char *package1;
-    char *package2;
-    char *reason;
-};
-
-struct __pmfileconflict_t {
-    char *target;
-    pmfileconflicttype_t type;
-    char *file;
-    char *ctarget;
-};
-
 typedef int           negative_is_error;
 typedef pmdb_t      * ALPM_DB;
 typedef pmpkg_t     * ALPM_Package;
 typedef pmpkg_t     * ALPM_PackageFree;
+typedef pmpkg_t     * ALPM_PackageOrNull;
 typedef pmgrp_t     * ALPM_Group;
 
 typedef pmdepend_t  * DependHash;
@@ -117,7 +73,7 @@ extern const char * log_lvl_unknown;
     RETVAL = ( cb_ ## CBTYPE ## _sub == NULL                \
                ? &PL_sv_undef : cb_ ## CBTYPE ## _sub );
 
-void cb_log_wrapper ( pmloglevel_t level, char * format, va_list args );
+void cb_log_wrapper ( pmloglevel_t level, const char * format, va_list args );
 void cb_dl_wrapper ( const char *filename, off_t xfered, off_t total );
 void cb_totaldl_wrapper ( off_t total );
 int  cb_fetch_wrapper ( const char *url, const char *localpath, int force );
@@ -159,23 +115,20 @@ void cb_trans_event_wrapper ( pmtransevt_t event,
 void cb_trans_conv_wrapper ( pmtransconv_t type,
                              void *arg_one, void *arg_two, void *arg_three,
                              int *result );
-void cb_trans_progress_wrapper( pmtransprog_t type,
-                                const char * desc,
-                                int item_progress,
-                                int total_count, int total_pos );
-
+void cb_trans_progress_wrapper ( pmtransprog_t type,
+                                 const char * desc,
+                                 int item_progress,
+                                 size_t total_count,
+                                 size_t total_pos );
+ 
 /* CONVERSION  *************************************************************/
 
 SV * convert_stringlist ( alpm_list_t * string_list );
 SV * convert_packagelist ( alpm_list_t * package_list );
-SV * convert_depend ( const pmdepend_t * depend );
-SV * convert_depmissing ( const pmdepmissing_t * depmiss );
-SV * convert_conflict ( const pmconflict_t * conflict );
-SV * convert_fileconflict ( const pmfileconflict_t * fileconflict );
-void free_stringlist_errors ( char *string );
-void free_fileconflict_errors ( pmfileconflict_t *conflict );
-void free_depmissing_errors ( pmdepmissing_t *miss );
-void free_conflict_errors ( pmconflict_t *conflict );
+SV * convert_depend ( pmdepend_t * depend );
+SV * convert_depmissing ( pmdepmissing_t * depmiss );
+SV * convert_conflict ( pmconflict_t * conflict );
+SV * convert_fileconflict ( pmfileconflict_t * fileconflict );
 SV * convert_trans_errors ( alpm_list_t * errors );
 
 #endif
